Supreme Court Opinions | Nebraska Judicial Branch

Skip to main content
We have a new email notification provider. If you haven't already, please subscribe to alerts again.
Oral Arguments are happening now. View them live »
Official Nebraska Government Website

## You are here

# Supreme Court Opinions

Friday, May 31, 2013
S-12-702 | 286 Neb. 1 | Estate of Teague v. Crossroads Co-op Assn. |
S-12-896 | 286 Neb. 16 | State v. Thacker |
S-13-323 | 286 Neb. 27 | State ex rel. Counsel for Dis. v. Stephenson |
|  | List of Cases Disposed of by Filed Memorandum Opinion |
|  | Weekly List of Cases Disposed of Without Opinion |
|  | Weekly List of Cases on Petition for Further Review |

Nebraska Judicial Branch